@@ -7,9 +7,11 @@ import ast
 import platform
 import sys
 import traceback
+from typing import Optional
+from typing import Sequence
 
 
-def check_ast(argv=None):
+def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
     parser = argparse.ArgumentParser()
     parser.add_argument('filenames', nargs='*')
     args = parser.parse_args(argv)
@@ -18,7 +20,8 @@ def check_ast(argv=None):
     for filename in args.filenames:
 
         try:
-            ast.parse(open(filename, 'rb').read(), filename=filename)
+            with open(filename, 'rb') as f:
+                ast.parse(f.read(), filename=filename)
         except SyntaxError:
             print('{}: failed parsing with {} {}:'.format(
                 filename,
@@ -33,4 +36,4 @@ def check_ast(argv=None):
 
 
 if __name__ == '__main__':
-    exit(check_ast())
+    exit(main())
