@@ -2,6 +2,8 @@ from __future__ import print_function
 
 import argparse
 import sys
+from typing import Optional
+from typing import Sequence
 
 BLACKLIST = [
     b'BEGIN RSA PRIVATE KEY',
@@ -9,10 +11,13 @@ BLACKLIST = [
     b'BEGIN EC PRIVATE KEY',
     b'BEGIN OPENSSH PRIVATE KEY',
     b'BEGIN PRIVATE KEY',
+    b'PuTTY-User-Key-File-2',
+    b'BEGIN SSH2 ENCRYPTED PRIVATE KEY',
+    b'BEGIN PGP PRIVATE KEY BLOCK',
 ]
 
 
-def detect_private_key(argv=None):
+def main(argv=None):  # type: (Optional[Sequence[str]]) -> int
     parser = argparse.ArgumentParser()
     parser.add_argument('filenames', nargs='*', help='Filenames to check')
     args = parser.parse_args(argv)
@@ -34,4 +39,4 @@ def detect_private_key(argv=None):
 
 
 if __name__ == '__main__':
-    sys.exit(detect_private_key())
+    sys.exit(main())
